# Simple Black-Scholes (simple-blackScholes)

Simple Black-Scholes library is a short python package with methods for calculating the values of option contracts using the Black-Scholes-Merton model.

## What it can do

Currently it can calculate the following

* For European-Style options:
    * Call option price,
    * Put option price.


## To Be Implemented

There are still a lot of features missing in the library. Currently these are the future aims of the project:

* Pricing functions for American-Style options.
* Option contract greek values.


## Licence

Licensing information can be found in the `LICENSE` file.